@@ -76,6 +76,11 @@ fn test_display(data: &[u8], expected: &'static str) {
     );
 }
 
+#[test]
+fn test_unpredictable_instructions() {
+    test_invalid(&[0x80, 0xfa, 0x40, 0x00]);
+}
+
 #[test]
 fn test_decode_add_cases() {
     test_display(
@@ -3579,6 +3584,14 @@ fn test_decode_str_32b_cases() {
         &[0xe3, 0xe9, 0x7e, 0x5a],
         "strd r5, r10, [r3, 0x1f8]!"
     );
+    test_display(
+        &[0x41, 0xf8, 0x04, 0x2b],
+        "str.w r2, [r1], 0x4"
+    );
+    test_display(
+        &[0x41, 0xf8, 0x00, 0x2b],
+        "str.w r2, [r1]"
+    );
 }
 
 #[test]
